Crate markerml_frontend

Crate markerml_frontend 

This is a crate that provides parser for the MarkerML language.

For the full grammar overview, refer to the markerml crate.

Re-exports

pub use parser::ParserError;
pub use span::Span;

Modules

ast
ast_span_helpers
parser
span

Functions

parse
Parses given code into AST